@@ -19,7 +19,8 @@ gint      ggv_default_width = DEFAULT_WINDOW_WIDTH;
 gint      ggv_default_height = DEFAULT_WINDOW_HEIGHT;
 
 gboolean ggv_panel = TRUE, ggv_menubar = TRUE, ggv_toolbar = TRUE;
-gboolean ggv_statusbar = TRUE, ggv_autojump = TRUE, ggv_pageflip = FALSE;
+gboolean ggv_statusbar = TRUE;
+gboolean ggv_autojump = TRUE, ggv_pageflip = FALSE;
 gboolean ggv_right_panel = FALSE, ggv_watch_doc = TRUE;
 
 gint ggv_unit_index = 0;
